# The Adsorber Program

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/)
[![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber)
[![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/)
[![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber)
[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)
[![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html)
[![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)

CURRENTLY UNDER RECONSTRUCTION: SOME FEATURES MAY NOT CURRENTLY BE WORKING

Authors: Geoffrey R. Weal and Dr. Anna L. Garden (University of Otago, Dunedin, New Zealand)

Group page: https://blogs.otago.ac.nz/annagarden/

## What is Adsorber

Adsorber is designed to adsorb molecules in various way to a cluster or surface. 

## Installation

It is recommended to read the installation page before using the Adsorber program. 

[adsorber.readthedocs.io/en/latest/Installation.html](https://adsorber.readthedocs.io/en/latest/Installation.html)

Note that you can install Adsorber through ``pip3`` and ``conda``. 

## Output files that are created by Adsorber

Adsorber will adsorb atoms and molecules on various binding sites across your cluster or surface model. An example of an COOH molecules adsorbed to a vertex site on a Cu<sub>78</sub> cluster is shown below

<p align="center">
	<img src="https://github.com/GardenGroupUO/Adsorber/blob/main/Documentation/source/Images/COOH_site_1_rotation_0.png">
</p>

## Where can I find the documentation for Adsorber

All the information about this program is found online at [adsorber.readthedocs.io/en/latest/](https://adsorber.readthedocs.io/en/latest/). Click the button below to also see the documentation: 

[![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/)

## About

<div align="center">

| Python | [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Adsorber)](https://docs.python.org/3/) | 
|:----------------------:|:-------------------------------------------------------------:|
| Repositories | [![GitHub release (latest by date)](https://img.shields.io/github/v/release/GardenGroupUO/Adsorber)](https://github.com/GardenGroupUO/Adsorber) [![PyPI](https://img.shields.io/pypi/v/Adsorber)](https://pypi.org/project/Adsorber/) [![Conda](https://img.shields.io/conda/v/gardengroupuo/adsorber)](https://anaconda.org/GardenGroupUO/adsorber) |
| Documentation | [![Documentation](https://img.shields.io/badge/Docs-click%20here-brightgreen)](https://adsorber.readthedocs.io/en/latest/) | 
| Tests | [![LGTM Grade](https://img.shields.io/lgtm/grade/python/github/GardenGroupUO/Adsorber)](https://lgtm.com/projects/g/GardenGroupUO/Adsorber/context:python)
| License | [![Licence](https://img.shields.io/github/license/GardenGroupUO/Adsorber)](https://www.gnu.org/licenses/agpl-3.0.en.html) |
| Authors | Geoffrey R. Weal, Dr. Anna L. Garden |
| Group Website | https://blogs.otago.ac.nz/annagarden/ |

</div>
